require File.expand_path('../../../../../../lib/nucleo/models/concerns/count', __FILE__)

RSpec.describe(Nucleo::Models::Concerns::Count) do
  let(:count) { 25 }
  let(:min) { 5 }
  let(:max) { 100 }

  subject { described_class.new(count, min, max) }

  context "within range" do
    it "returns false for #missing?" do
      expect(subject.missing?).to be(false)
    end

    it "returns true for #multiple?" do
      expect(subject.multiple?).to be(true)
    end

    it "returns false for #too_few?" do
      expect(subject.too_few?).to be(false)
    end

    it "returns true for #max?" do
      expect(subject.max?).to be(true)
    end

    it "returns false for #too_many?" do
      expect(subject.too_many?).to be(false)
    end
  end

  context "missing" do
    let(:count) { 0 }

    it "returns true for #missing?" do
      expect(subject.missing?).to be(true)
    end

    it "returns false for #multiple?" do
      expect(subject.multiple?).to be(false)
    end

    it "returns true for #too_few?" do
      expect(subject.too_few?).to be(true)
    end

    it "returns true for #max?" do
      expect(subject.max?).to be(true)
    end

    it "returns false for #too_many?" do
      expect(subject.too_many?).to be(false)
    end
  end

  context "too many" do
    let(:count) { 101 }

    it "returns false for #missing?" do
      expect(subject.missing?).to be(false)
    end

    it "returns true for #multiple?" do
      expect(subject.multiple?).to be(true)
    end

    it "returns false for #too_few?" do
      expect(subject.too_few?).to be(false)
    end

    it "returns true for #max?" do
      expect(subject.max?).to be(true)
    end

    it "returns true for #too_many?" do
      expect(subject.too_many?).to be(true)
    end
  end

  context "without max" do
    let(:max) { 0 }

    it "returns false for #missing?" do
      expect(subject.missing?).to be(false)
    end

    it "returns true for #multiple?" do
      expect(subject.multiple?).to be(true)
    end

    it "returns false for #too_few?" do
      expect(subject.too_few?).to be(false)
    end

    it "returns false for #max?" do
      expect(subject.max?).to be(false)
    end

    it "returns false for #too_many?" do
      expect(subject.too_many?).to be(false)
    end
  end
end
