require File.expand_path('../../../../../../lib/nucleo/models/concerns/length', __FILE__)

RSpec.describe(Nucleo::Models::Concerns::Length) do
  let(:total) { 25 }
  let(:min) { 5 }
  let(:max) { 50 }

  subject { described_class.new(total, min, max) }

  context "within range" do
    it "returns true for #max?" do
      expect(subject.max?).to be(true)
    end

    it "returns false for #too_short?" do
      expect(subject.too_short?).to be(false)
    end

    it "returns -20 for #too_short_length" do
      expect(subject.too_short_length).to eq(-20)
    end

    it "returns false for #too_long?" do
      expect(subject.too_long?).to be(false)
    end

    it "returns -25 for #too_long_length" do
      expect(subject.too_long_length).to eq(-25)
    end
  end

  context "too short" do
    let(:total) { 4 }

    it "returns true for #max?" do
      expect(subject.max?).to be(true)
    end

    it "returns true for #too_short?" do
      expect(subject.too_short?).to be(true)
    end

    it "returns 1 for #too_short_length" do
      expect(subject.too_short_length).to eq(1)
    end

    it "returns false for #too_long?" do
      expect(subject.too_long?).to be(false)
    end

    it "returns -46 for #too_long_length" do
      expect(subject.too_long_length).to eq(-46)
    end
  end

  context "too long" do
    let(:total) { 51 }

    it "returns true for #max?" do
      expect(subject.max?).to be(true)
    end

    it "returns false for #too_short?" do
      expect(subject.too_short?).to be(false)
    end

    it "returns -46 for #too_short_length" do
      expect(subject.too_short_length).to eq(-46)
    end

    it "returns true for #too_long?" do
      expect(subject.too_long?).to be(true)
    end

    it "returns 1 for #too_long_length" do
      expect(subject.too_long_length).to eq(1)
    end
  end
end
