require 'multi_json'

require File.expand_path('../../../../../lib/nucleo/models/metric_periods_comparisons', __FILE__)

RSpec.describe(Nucleo::Models::MetricPeriodsComparison) do
  let(:model_attributes) do
    {
      'dimension'     => 'Google',
      'current_value' => 3445,
      'prior_value'   => 2340,
      'change'        => 23
    }
  end

  subject { described_class.new(model_attributes) }

  context "with valid values" do
    it "returns the #dimension" do
      expect(subject.dimension).to eq('Google')
    end

    it "returns the #current_value" do
      expect(subject.current_value).to eq(3445)
    end

    it "returns the #prior_value" do
      expect(subject.prior_value).to eq(2340)
    end

    it "returns the percent #change" do
      expect(subject.change).to eq(23)
    end

    describe "#direction" do
      it "returns 'up' with a positive change" do
        expect(subject.direction).to eq('up')
      end

      it "returns 'same' with a no change" do
        model_attributes['change'] = 0
        expect(subject.direction).to eq('same')
      end

      it "returns 'down' with a negative change" do
        model_attributes['change'] = -23
        expect(subject.direction).to eq('down')
      end
    end
  end
end
